@@ -130,14 +130,14 @@ def delete_nanfilled_lines(data, variables=False, inplace=False, count=True):
     if count:
       datasize = data.shape[0]
     if inplace:
-      df_union.dropna(subset=variables, how="all", inplace=True)
+      data.dropna(subset=variables, how="all", inplace=True)
       if count:
-        print(f"\033[1m{datasize - df_union.shape[0]} lignes ont été supprimées.\033[0m")
+        print(f"\033[1m{datasize - data.shape[0]} lignes ont été supprimées.\033[0m")
     else:
       if count:
-        print(f"\033[1m{datasize - df_union.shape[0]} lignes ont été supprimées.\033[0m")
-      return df_union.dropna(subset=variables, how="all")
-      
+        print(f"\033[1m{datasize - data.shape[0]} lignes ont été supprimées.\033[0m")
+      return data.dropna(subset=variables, how="all")
+
 def df_description(data, col_count=False, return_only=False):
     """Description des variables enrichie de 2 colonnes = nombre de nan et % de nan
     
